#
# spec file for package cloud-netconfig
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define base_name cloud-netconfig

%if "ec2" == ""
%define flavor_suffix %nil
%define csp_string None
ExclusiveArch:  do-not-build
%endif
%if "ec2" == "azure"
%define flavor_suffix -azure
%define csp_string Microsoft Azure
%endif
%if "ec2" == "ec2"
%define flavor_suffix -ec2
%define csp_string Amazon EC2
%endif

Name:           %{base_name}%{flavor_suffix}
Version:        0.7
Release:        10.1
Summary:        Network configuration scripts for %{csp_string}
License:        GPL-3.0-or-later
Group:          System/Management
Url:            https://github.com/SUSE/Enceladus
Source0:        %{base_name}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%if 0%{?suse_version} == 1110
BuildRequires:  sysconfig
Requires:       sysconfig
%define _udevrulesdir %{_sysconfdir}/udev/rules.d
%else
BuildRequires:  sysconfig-netconfig
Requires:       sysconfig-netconfig
%endif
BuildRequires:  udev
Requires:       curl
Requires:       udev
%if 0%{?sles_version} == 11
# RPM in SLES 11 does not support self conflict, use otherproviders()
# workaround
Provides:       cloud-netconfig
Conflicts:      otherproviders(cloud-netconfig)
%else
Provides:       cloud-netconfig
Conflicts:      cloud-netconfig
%endif

%description -n %{base_name}%{flavor_suffix}
This package contains scripts for automatically configuring network interfaces
in %{csp_string} with full support for hotplug.

%prep
%setup -q -n %{base_name}-%{version}

%build

%install
make install%{flavor_suffix} \
  DESTDIR=%{buildroot} \
  PREFIX=%{_usr} \
  SYSCONFDIR=%{_sysconfdir} \
  UDEVRULESDIR=%{_udevrulesdir}

# Disable persistent net generator from udev-persistent-ifnames as
# it does not work for xen interfaces. This will likely produce a warning.
%if 0%{?suse_version} >= 1315
mkdir -p %{buildroot}/%{_sysconfdir}/udev/rules.d
ln -s /dev/null %{buildroot}/%{_sysconfdir}/udev/rules.d/75-persistent-net-generator.rules
%endif

%files -n %{base_name}%{flavor_suffix}
%defattr(-,root,root)
%{_sysconfdir}/netconfig.d/cloud-netconfig
%{_sysconfdir}/sysconfig/network/scripts/*
%if 0%{?suse_version} >= 1315
%{_sysconfdir}/udev/rules.d
%endif
%{_udevrulesdir}/*
%doc README.md LICENSE

%changelog
* Tue May 29 2018 jgleissner@suse.com
- Update to version 0.7:
  + no persistent names in Azure (bsc#1094271)
* Wed Jan 17 2018 jgleissner@suse.com
- Added dependency on curl
- Use otherproviders() only on SLES 11 builds
* Fri Jan 12 2018 jgleissner@suse.com
- Remove dependency on udev-persistent-ifnames (bsc#1075484)
* Thu Nov  9 2017 adrian.glaubitz@suse.com
- Add missing Provides/Conflicts statements to spec file
* Fri Oct 13 2017 jgleissner@suse.com
- Prepare for SLE11 submission (bsc#1063292)
* Fri Oct 13 2017 jgleissner@suse.com
- Update to version 0.6:
  + Use tested and supported metadata API versions
* Wed Oct 11 2017 rjschwei@suse.com
- Update to version 0.5
  + New API version for Azure metadata server
  + Wait for the metadata server in EC2
* Tue Oct 10 2017 jgleissner@suse.com
- Update to version 0.4:
  Do not touch VF interfaces in Azure (bsc#1055553)
- Prepare for SLE submission (FATE#323820, bsc#1027212)
* Thu Sep  7 2017 jgleissner@suse.com
- Added conflict tags
- Fix requires for non-Leap platforms
* Mon Aug 14 2017 jgleissner@suse.com
- Initial version 0.3
